from django.shortcuts import render
from .forms import LoginForm, MessageForm
from .models import Message
from django.contrib.auth import authenticate, login, logout
from django.contrib.auth.models import User
from django.http import HttpResponseRedirect, Http404

# Create your views here.
def login_view(request):
    if request.method == "POST":
        form = LoginForm(request.POST)
        if form.is_valid(): # Если форма в порядке
            username = form.cleaned_data["username"].strip()
            password = form.cleaned_data["password"]
            user = authenticate(username=username, password=password)
            if user is None:
                form.add_error("username", "Неправильный логин или пароль")
            else:
                login(request, user)
                goto = request.GET.get("next", "/")
                return HttpResponseRedirect(goto)
    else:
        form = LoginForm()
    return render(request, "login.html", context={"form": form})


def messages_view(request, folder="inbox"):
    messages = []
    inbox = False
    if folder == "inbox":
        messages = Message.objects.filter(addressee=request.user).order_by("-date_sent")
        inbox = True
    elif folder == "outbox":
        messages = Message.objects.filter(sender=request.user).order_by("-date_sent")
    return render(request, "messages.html", context={
        "messages": messages, "inbox": inbox})


def new_message_view(request):
    if request.method == "POST":
        form = MessageForm(request.POST)
        if form.is_valid():
            addressee_name = form.cleaned_data["addressee"]
            subj = form.cleaned_data["subject"]
            body = form.cleaned_data["body"]
            try:
                addressee = User.objects.get(username=addressee_name)
            except User.DoesNotExist:
                form.add_error("addressee", "Такой пользователь не существует")
            else:
                m = Message(addressee=addressee, sender=request.user,
                    subject=subj, body=body)
                m.save()
                return HttpResponseRedirect("/outbox/")
    else:
        form = MessageForm()
    return render(request, "new_message.html", context={"form": form})


def message_sent_view(request):
    pass


def full_message_view(request, id):
    try:
        message = Message.objects.get(id=id)
    except Message.DoesNotExist:
        raise Http404
    if message.addressee == request.user or message.sender == request.user:
        return render(request, "full_message.html", context={"message": message})
    else:
        raise Http404


def logout_view(request):
    if request.user.is_authenticated:
        logout(request)
    return HttpResponseRedirect("/login/")
